aboutsummaryrefslogtreecommitdiff
path: root/tests/manifest/driver.cxx
diff options
context:
space:
mode:
authorKaren Arutyunov <karen@codesynthesis.com>2018-02-14 19:27:47 +0300
committerKaren Arutyunov <karen@codesynthesis.com>2018-02-15 11:08:22 +0300
commit18e40e91c99088ef5fb9458ec4c1ec21ddcc51e6 (patch)
treebbb91a98a375e9cae387f03a7ca1ef32db202d73 /tests/manifest/driver.cxx
parent02458785b93094dfc65b31a4ecf2a8e690143b03 (diff)
Add support for git manifests
Diffstat (limited to 'tests/manifest/driver.cxx')
-rw-r--r--tests/manifest/driver.cxx18
1 files changed, 12 insertions, 6 deletions
diff --git a/tests/manifest/driver.cxx b/tests/manifest/driver.cxx
index b7a87eb..9c58dcf 100644
--- a/tests/manifest/driver.cxx
+++ b/tests/manifest/driver.cxx
@@ -21,8 +21,10 @@ using namespace bpkg;
// Read and parse manifest from STDIN and serialize it to STDOUT. The
// following options specify the manifest type.
//
// -p parse package manifest list
// -r parse repository manifest list
// -s parse signature manifest
//
int
@@ -37,10 +39,14 @@ main (int argc, char* argv[])
manifest_parser p (cin, "stdin");
manifest_serializer s (cout, "stdout");
- if (opt == "-p")
- package_manifests (p).serialize (s);
- else if (opt == "-r")
- repository_manifests (p).serialize (s);
+ if (opt == "-bp")
+ bpkg_package_manifests (p).serialize (s);
+ else if (opt == "-br")
+ bpkg_repository_manifests (p).serialize (s);
+ else if (opt == "-gp")
+ git_package_manifests (p).serialize (s);
+ else if (opt == "-gr")
+ git_repository_manifests (p).serialize (s);
else if (opt == "-s")
signature_manifest (p).serialize (s);
else
@@ -21,8 +21,10 @@ using namespace bpkg;
// following options specify the manifest type.
//
-// -p parse package manifest list
-// -r parse repository manifest list
+// -bp parse bpkg package manifest list
+// -gp parse git package manifest list
+// -br parse bpkg repository manifest list
+// -gr parse git repository manifest list
// -s parse signature manifest
//